# Intentional - OpenAI

[![PyPI - Version](https://img.shields.io/pypi/v/intentional-openai.svg)](https://pypi.org/project/intentional-openai)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/intentional-openai.svg)](https://pypi.org/project/intentional-openai)
[![Copier](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/copier-org/copier/master/img/badge/badge-grayscale-inverted-border-orange.json)](https://github.com/copier-org/copier)

Intentional plugin for OpenAI.

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install intentional-openai
```

To use the Realtime API:

```
sudo apt install ffmpeg portaudio19-dev
```

## License

`intentional` is distributed under the terms of the [AGPL](LICENSE.txt) license.
